@@ -1,4 +1,4 @@
-from typing import Callable
+from typing import Callable, Optional
 from typing import TypeVar, Generic
 
 K = TypeVar('K')
@@ -13,3 +13,9 @@ class EzList(Generic[T], list[T]):
 
     def filter(self, predicate: Callable[[T], bool]) -> "EzList[T]":
         return EzList([v for v in self if predicate(v)])
+
+    def find(self, predicate: Callable[[T], bool]) -> Optional[T]:
+        for v in self:
+            if predicate(v):
+                return v
+        return None
